@@ -3,6 +3,7 @@ package resources
 import (
 	"fmt"
 
+	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/route53"
 	"github.com/rebuy-de/aws-nuke/pkg/types"
@@ -23,10 +24,20 @@ func ListRoute53HostedZones(sess *session.Session) ([]Resource, error) {
 
 	resources := make([]Resource, 0)
 	for _, hz := range resp.HostedZones {
+		tags, err := svc.ListTagsForResource(&route53.ListTagsForResourceInput{
+			ResourceId:   hz.Id,
+			ResourceType: aws.String("hostedzone"),
+		})
+
+		if err != nil {
+			return nil, err
+		}
+
 		resources = append(resources, &Route53HostedZone{
 			svc:  svc,
 			id:   hz.Id,
 			name: hz.Name,
+			tags: tags.ResourceTagSet.Tags,
 		})
 	}
 	return resources, nil
@@ -36,6 +47,7 @@ type Route53HostedZone struct {
 	svc  *route53.Route53
 	id   *string
 	name *string
+	tags []*route53.Tag
 }
 
 func (hz *Route53HostedZone) Remove() error {
@@ -52,8 +64,12 @@ func (hz *Route53HostedZone) Remove() error {
 }
 
 func (hz *Route53HostedZone) Properties() types.Properties {
-	return types.NewProperties().
-		Set("Name", hz.name)
+	properties := types.NewProperties()
+	for _, tag := range hz.tags {
+		properties.SetTag(tag.Key, tag.Value)
+	}
+	properties.Set("Name", hz.name)
+	return properties
 }
 
 func (hz *Route53HostedZone) String() string {
